<a href="https://cognite.com/">
    <img src="https://github.com/cognitedata/cognite-graphic-profile/blob/master/cognite_logo.png" alt="Cognite logo" title="Cognite" align="right" height="80" />
</a>

Cognite Model Hosting Utilities
===============================
[![Build Status](https://jenkins.cognite.ai/buildStatus/icon?job=github-builds/cognite-model-hosting/master)](https://jenkins.cognite.ai/job/github-builds/job/cognite-model-hosting/job/master/)
[![codecov](https://codecov.io/gh/cognitedata/cognite-data-fetcher/branch/master/graph/badge.svg?token=0715UMyLlV)](https://codecov.io/gh/cognitedata/cognite-data-fetcher)
[![PyPI version](https://badge.fury.io/py/cognite-data-fetcher.svg)](https://pypi.org/project/cognite-data-fetcher/)
[![tox](https://img.shields.io/badge/tox-3.5%2B-blue.svg)](https://www.python.org/downloads/release/python-350/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)

Utilities for Cognite model hosting environment.

## Documentation
* [Model Hosting Utilities Documentation](https://cognite-model-hosting.readthedocs-hosted.com/en/latest/)
* [SDK Documentation](https://cognite-sdk-python.readthedocs-hosted.com/en/latest/)
* [API Documentation](https://doc.cognitedata.com/)

## Installation
```bash
$ pip install cognite-model-hosting
```
